# -*- coding: utf-8 -*-
"""
@Time ： 2022/7/24 15:46
@Auth ： Gancheng Yuan
"""
from distutils.core import setup
setup(
  name='leetcodeutils',
  packages=['leetcodeutils'],
  version='0.4',
  license='MIT',
  description='some useful utilities for coding with Leetcode',
  author='Gancheng Yuan',
  author_email='scottyuan@outlook.com',
  url='https://github.com/mqfs/leetcodeutils',
  download_url='https://github.com/mqfs/leetcodeutils/archive/refs/tags/v0.4.tar.gz',
  keywords=['leetcode', 'debug'],
  install_requires=[],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
  ],
)
