# -*- coding: utf-8 -*-
"""
@Time ： 2022/7/25 1:09
@Auth ： Gancheng Yuan
"""


class ListNode:
    def __init__(self, val=0, next=None):
        self.val = val
        self.next = next


class TreeNode:
    def __init__(self, val=0, left=None, right=None):
        self.val = val
        self.left = left
        self.right = right


null = None
